/**
 * La liste des noms des formateurs.
 *
 * @constant {string[]} FORMATTERS
 */
export const FORMATTERS: string[];
/**
 * Le formateur parent.
 */
export default class Formatter {
    /**
     * Crée un formateur.
     *
     * @param {Level} level Le niveau de sévérité minimum des notifications
     *                      affichées.
     */
    constructor(level: Level);
    /**
     * Retourne le niveau de sévérité minimum des notifications affichées.
     *
     * @returns {Level} Le niveau de sévérité.
     */
    get level(): number;
    /**
     * Traite les notifications d'un fichier analysé.
     *
     * @param {string}             _file    Le fichier analysé.
     * @param {Notice[]|undefined} _notices La liste des notifications ou
     *                                      <code>undefined</code>.
     * @returns {Promise<void>} La promesse indiquant que les notifications ont
     *                          été traitées.
     */
    notify(_file: string, _notices: Notice[] | undefined): Promise<void>;
    /**
     * Finalise les résultats.
     *
     * @returns {Promise<void>} La promesse indiquant que les résultats ont été
     *                          finalisés.
     */
    finalize(): Promise<void>;
    #private;
}
export type Level = import("../../type/index.js").Level;
export type Notice = import("../../type/index.js").Notice;
