/**
 * @typedef {import("node:stream").Writable} Writable
 * @typedef {import("../../type/index.js").Level} Level
 * @typedef {import("../../type/index.js").Notice} Notice
 */
/**
 * Le formateur qui écrit les résultats bruts (au format JSON). La seule
 * altération des résultats est le remplacement des <code>undefined</code> par
 * des <code>null</code>.
 *
 * @see https://www.json.org/
 */
export default class JSONFormatter extends Formatter {
    /**
     * Crée un formateur.
     *
     * @param {Level}    level            Le niveau de sévérité minimum des
     *                                    notifications affichées.
     * @param {Object}   options          Les options du formateur.
     * @param {Writable} [options.writer] Le flux où écrire les résultats.
     * @param {number}   [options.indent] La taille des indentations (en
     *                                    espace).
     */
    constructor(level: Level, options: {
        writer?: Writable;
        indent?: number;
    });
    #private;
}
export type Writable = import("node:stream").Writable;
export type Level = import("../../type/index.js").Level;
export type Notice = import("../../type/index.js").Notice;
import Formatter from "./formatter.js";
