/**
 * Le développeur de motif.
 *
 * @see https://en.wikipedia.org/wiki/Glob_(programming)
 */
export default class Glob {
    /**
     * Crée un développeur de motif.
     *
     * @param {string|string[]} patterns      Le ou les patrons.
     * @param {Object}          options       Les options du développeur de
     *                                        motif.
     * @param {string}          [options.cwd] Le chemin du répertoire courant.
     * @param {string}          options.root  Le chemin du répertoire où se
     *                                        trouve le répertoire
     *                                        <code>.metalint/</code>.
     */
    constructor(patterns: string | string[], { cwd, root }: {
        cwd?: string;
        root: string;
    });
    /**
     * Vérifie si un fichier / répertoire respecte les patrons.
     *
     * @param {string} file Le chemin du fichier / répertoire qui sera vérifié.
     * @returns {boolean} <code>true</code> si le fichier / répertoire respecte
     *                    les patrons ; sinon <code>false</code>.
     */
    test(file: string): boolean;
    /**
     * Récupère toute l'arborescence d'un répertoire respectant les patrons.
     *
     * @param {string} base Le répertoire servant de racine pour l'arborescence.
     * @returns {Promise<string[]>} Une promesse contenant la liste des fichiers
     *                              / répertoires respectant les patrons.
     */
    walk(base: string): Promise<string[]>;
    #private;
}
