/**
 * La liste des noms des enrobages.
 *
 * @constant {string[]} WRAPPERS
 */
export const WRAPPERS: string[];
/**
 * La classe mère des enrobages de linters.
 */
export default class Wrapper {
    /**
     * Crée un enrobage pour un linter.
     *
     * @param {Object}   context       Le contexte de l'enrobage.
     * @param {Level}    context.level Le niveau de sévérité minimum des
     *                                 notifications retournées.
     * @param {boolean}  context.fix   La marque indiquant s'il faut corriger le
     *                                 fichier.
     * @param {string}   context.root  L'adresse du répertoire où se trouve le
     *                                 répertoire <code>.metalint/</code>.
     * @param {string[]} context.files La liste de tous les fichiers analysés.
     */
    constructor({ level, fix, root, files }: {
        level: Level;
        fix: boolean;
        root: string;
        files: string[];
    });
    /**
     * Retourne le niveau de sévérité minimum des notifications retournées.
     *
     * @returns {Level} Le niveau de sévérité minimum des notifications
     *                  retournées.
     */
    get level(): number;
    /**
     * Retourne la marque indiquant s'il faut corriger les fichiers.
     *
     * @returns {boolean} La marque indiquant s'il faut corriger les fichiers.
     */
    get fix(): boolean;
    /**
     * Retourne l'adresse du répertoire où se trouve le répertoire
     * <code>.metalint/</code>.
     *
     * @returns {string} L'adresse du répertoire où se trouve le répertoire
     *                   <code>.metalint/</code>.
     */
    get root(): string;
    /**
     * Retourne la liste des fichiers analysés.
     *
     * @returns {string[]} La liste des fichiers analysés.
     */
    get files(): string[];
    /**
     * Vérifie un fichier.
     *
     * @param {string} _file Le fichier qui sera vérifié.
     * @returns {Promise<PartialNotice[]>} Une promesse retournant la liste des
     *                                     notifications.
     */
    lint(_file: string): Promise<PartialNotice[]>;
    #private;
}
export type Level = import("../../type/index.d.ts").Level;
export type PartialNotice = import("../../type/index.d.ts").PartialNotice;
